;; Generated package description from wcheck-mode.el  -*- no-byte-compile: t -*-
(define-package "wcheck-mode" "2020.10.4.0.20210206.154232" "General interface for text checkers" 'nil :keywords '("text" "spell" "check" "languages" "ispell") :authors '(("Teemu Likonen" . "tlikonen@iki.fi")) :maintainer '("Teemu Likonen" . "tlikonen@iki.fi") :url "https://github.com/tlikonen/wcheck-mode")
